@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ReadLocker.h 2483 2007-07-03 13:17:30Z svn $
+ * $Id: ReadLocker.h 2484 2007-07-03 15:14:44Z svn $
  *****************************************************************************/
 
 #ifndef READ_LOCKER_H
@@ -52,33 +52,33 @@ public:
       : ReadWriteLocker(lock)
     {
         apr_size_t try_count;
-        apr_uint32_t status;
+        apr_uint32_t curr_status;
         apr_uint32_t new_status;
 
         try_count = 0;
         while (1) {
             try_count++;
 
-            status = apr_atomic_read(lock_);
-            if (LIKELY((get_read_count(status) != WRITE_LOCKED) &&
-                       ((get_wait_write(status) != WAIT_WRITE) ||
-                        (get_prefer_write(status) != PREFER_WRITE)))) {
-                new_status = make_status(get_age(status),
-                                         get_read_count(status) + 1,
-                                         get_prefer_write(status),
-                                         get_wait_write(status));
-                if (apr_atomic_cas(lock_, new_status, status) == status) {
+            curr_status = apr_atomic_read(lock_);
+            if (LIKELY((get_read_count(curr_status) != WRITE_LOCKED) &&
+                       ((get_wait_write(curr_status) != WAIT_WRITE) ||
+                        (get_prefer_write(curr_status) != PREFER_WRITE)))) {
+                new_status = make_status(get_age(curr_status),
+                                         get_read_count(curr_status) + 1,
+                                         get_prefer_write(curr_status),
+                                         get_wait_write(curr_status));
+                if (apr_atomic_cas(lock_, new_status, curr_status) == curr_status) {
                     status_ = new_status;
                     log_try_count("ReadLock", try_count);
                     return;
                 }
             } else if (((try_count & TIMEOUT_CHECK_MASK) == 0) &&
-                       is_timeout(status)) {
+                       is_timeout(curr_status)) {
                 // タイムアウトしたら age を増やす
-                new_status = make_status(get_age(status) + 1, 1,
-                                         get_prefer_write(status),
-                                         get_wait_write(status));
-                if (apr_atomic_cas(lock_, new_status, status) == status) {
+                new_status = make_status(get_age(curr_status) + 1, 1,
+                                         get_prefer_write(curr_status),
+                                         get_wait_write(curr_status));
+                if (apr_atomic_cas(lock_, new_status, curr_status) == curr_status) {
                     status_ = new_status;
                     log_try_count("ReadLock(TIME OUT)", try_count);
                     return;
@@ -91,25 +91,27 @@ public:
     ~ReadLocker()
     {
         apr_size_t try_count;
-        apr_uint32_t status;
+        apr_uint32_t curr_status;
 
         try_count = 0;
         while (1) {
             try_count++;
 
-            status = apr_atomic_read(lock_);
-            if (get_age(status) != get_age(status_)) {
+            curr_status = apr_atomic_read(lock_);
+            if (get_age(curr_status) != get_age(status_)) {
                 // 他のスレッドにてタイムアウト処理がされた
                 log_try_count("ReadUnLock(TIME OUT)", try_count);
                 return;
             }
 
+            // read_count は変更されている可能性があることに注意！
+
             if (apr_atomic_cas(lock_,
-                               make_status(get_age(status),
-                                           get_read_count(status) - 1,
+                               make_status(get_age(curr_status),
+                                           get_read_count(curr_status) - 1,
                                            PREFER_WRITE,
-                                           get_wait_write(status)),
-                               status) == status) {
+                                           get_wait_write(curr_status)),
+                               curr_status) == curr_status) {
                 log_try_count("ReadUnLock", try_count);
                 return;
             }
