@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemManager.h 2472 2007-06-30 19:40:38Z svn $
+ * $Id: UploadItemManager.h 2485 2007-07-03 15:30:09Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_ITEM_MANAGER_H
@@ -125,6 +125,14 @@ private:
 
     UploadItemManager(apr_pool_t *pool, const char *data_dir_path,
                       const char *file_dir_path, const char *thumb_dir_path);
+    apr_size_t add_impl(apr_pool_t *pool,
+                        const char *file_name, const char *file_mime,
+                        apr_uint64_t file_size, const char *file_digest,
+                        const char *file_temp_path, const char *remove_pass,
+                        const char *download_pass, const char *comment,
+                        const char *ip_address);
+    void remove_impl(apr_pool_t *pool, UploadItem *uitem);
+
     /**
      * 子プロセス用の初期化を行います．
      *
