@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: WriteLocker.h 2483 2007-07-03 13:17:30Z svn $
+ * $Id: WriteLocker.h 2485 2007-07-03 15:30:09Z svn $
  *****************************************************************************/
 
 #ifndef WRITE_LOCKER_H
@@ -42,7 +42,7 @@
 using namespace std;
 
 /**
- * @brief 書き込みロックを表すクラス．
+q * @brief 書き込みロックを表すクラス．
  */
 class WriteLocker: public ReadWriteLocker
 {
@@ -56,40 +56,41 @@ public:
       : ReadWriteLocker(lock)
     {
         apr_size_t try_count;
-        apr_uint32_t status;
+        apr_uint32_t curr_status;
         apr_uint32_t new_status;
 
         try_count = 0;
         while (1) {
             try_count++;
 
-            status = apr_atomic_read(lock_);
-            if (LIKELY(get_read_count(status) == NOT_LOCKED)) {
-                new_status = make_status(get_age(status), WRITE_LOCKED);
-                if (apr_atomic_cas(lock_, new_status, status) == status) {
+            curr_status = apr_atomic_read(lock_);
+            if (LIKELY(get_read_count(curr_status) == NOT_LOCKED)) {
+                new_status = make_status(get_age(curr_status), WRITE_LOCKED);
+                if (apr_atomic_cas(lock_, new_status, curr_status) == curr_status) {
                     status_ = new_status;
                     log_try_count("WriteLock", try_count);
                     return;
                 }
             } else {
                 if (((try_count & TIMEOUT_CHECK_MASK) == 0) &&
-                    is_timeout(status)) {
+                    is_timeout(curr_status)) {
                     // タイムアウトしたら age を増やす
-                    new_status = make_status(get_age(status) + 1, WRITE_LOCKED);
-                    if (apr_atomic_cas(lock_, new_status, status) == status) {
+                    new_status = make_status(get_age(curr_status) + 1,
+                                             WRITE_LOCKED);
+                    if (apr_atomic_cas(lock_, new_status, curr_status) == curr_status) {
                         status_ = new_status;
                         log_try_count("WriteLock(TIME OUT)", try_count);
                         return;
                     }
                 }
 
-                if (get_wait_write(status) != WAIT_WRITE) {
+                if (get_wait_write(curr_status) != WAIT_WRITE) {
                     (void)apr_atomic_cas(lock_,
-                                         make_status(get_age(status),
-                                                     get_read_count(status),
-                                                     get_prefer_write(status),
+                                         make_status(get_age(curr_status),
+                                                     get_read_count(curr_status),
+                                                     get_prefer_write(curr_status),
                                                      WAIT_WRITE),
-                                         status);
+                                         curr_status);
                 }
             }
 
@@ -99,24 +100,25 @@ public:
     ~WriteLocker()
     {
         apr_size_t try_count;
-        apr_uint32_t status;
+        apr_uint32_t curr_status;
 
         try_count = 0;
         while (1) {
             try_count++;
 
-            status = apr_atomic_read(lock_);
-            if (get_age(status) != get_age(status_)) {
+            curr_status = apr_atomic_read(lock_);
+            if (get_age(curr_status) != get_age(status_)) {
                 // 他のスレッドにてタイムアウト処理がされた
                 log_try_count("WriteUnLock(TIME OUT)", try_count);
                 return;
             }
 
             if (apr_atomic_cas(lock_,
-                               make_status(get_age(status), NOT_LOCKED,
+                               make_status(get_age(curr_status),
+                                           NOT_LOCKED,
                                            PREFER_NONE,
-                                           get_wait_write(status)),
-                               status) == status) {
+                                           get_wait_write(curr_status)),
+                               curr_status) == curr_status) {
                 log_try_count("WriteUnLock", try_count);
                 return;
             }
