@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ApacheRequestReader.cpp 2439 2007-06-26 14:30:09Z svn $
+ * $Id: ApacheRequestReader.cpp 2461 2007-06-29 18:09:05Z svn $
  *****************************************************************************/
 
 #include "ApacheRequestReader.h"
@@ -38,7 +38,11 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: ApacheRequestReader.cpp 2439 2007-06-26 14:30:09Z svn $");
+SOURCE_INFO_ADD("$Id: ApacheRequestReader.cpp 2461 2007-06-29 18:09:05Z svn $");
+
+const apr_size_t ApacheRequestReader::READ_SLEEP_FACTOR = 16;
+const apr_size_t ApacheRequestReader::READ_SLEEP_USEC   = 100000;
+
 
 /******************************************************************************
  * public メソッド
@@ -90,6 +94,12 @@ void ApacheRequestReader::read(char *buffer, apr_size_t size, apr_size_t *read_s
 
     bucket_ = APR_BUCKET_NEXT(bucket_);
 
+    // リクエストしたサイズよりも大幅に小さいサイズしか read できなかっ
+    // た場合は少し待つ
+    if (*read_size < (size/READ_SLEEP_FACTOR)) {
+        apr_sleep(READ_SLEEP_USEC);
+    }
+
     return;
 }
 
