@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PostFlowController.cpp 2483 2007-07-03 13:17:30Z svn $
+ * $Id: PostFlowController.cpp 2485 2007-07-03 15:30:09Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -34,7 +34,7 @@
 #include "WriteLocker.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: PostFlowController.cpp 2483 2007-07-03 13:17:30Z svn $");
+SOURCE_INFO_ADD("$Id: PostFlowController.cpp 2485 2007-07-03 15:30:09Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -51,7 +51,7 @@ bool PostFlowController::can_post(apr_sockaddr_t *sockaddr)
 {
     apr_time_t time_limit;
 
-//     ReadLocker lock(&lock_);
+    ReadLocker lock(&lock_);
 
     // MEMO: 短時間の間に異なる ARRAY_SIZE_OF(poster_list_) 個の IP ア
     // ドレスから投稿があった場合，制限に漏れが生じる．
