@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ReadWriteLocker.cpp 2464 2007-06-30 01:47:25Z svn $
+ * $Id: ReadWriteLocker.cpp 2472 2007-06-30 19:40:38Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -30,7 +30,7 @@
 #include "ReadWriteLocker.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: ReadWriteLocker.cpp 2464 2007-06-30 01:47:25Z svn $");
+SOURCE_INFO_ADD("$Id: ReadWriteLocker.cpp 2472 2007-06-30 19:40:38Z svn $");
 
 
 /******************************************************************************
@@ -52,9 +52,6 @@ bool ReadWriteLocker::is_timeout(apr_uint32_t status)
     }
 
     if (UNLIKELY(apr_time_sec(curr_time - start_time_) > TIMEOUT_SEC)) {
-        std::cout << "TIMEOUT" <<std::endl;
-        std::cerr << "TIMEOUT" <<std::endl;
-
         return true;
     } else {
         return false;
