@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemManager.cpp 2472 2007-06-30 19:40:38Z svn $
+ * $Id: UploadItemManager.cpp 2491 2007-07-04 13:17:09Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -49,7 +49,7 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: UploadItemManager.cpp 2472 2007-06-30 19:40:38Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemManager.cpp 2491 2007-07-04 13:17:09Z svn $");
 
 #ifdef DEBUG
 #include <iostream>
@@ -89,43 +89,18 @@ void UploadItemManager::init(UploadItemList *item_list,
 
 apr_size_t UploadItemManager::add(apr_pool_t *pool,
                                   const char *file_name, const char *file_mime,
-                                  apr_uint64_t file_size, const char *file_digest,
+                                  apr_uint64_t file_size,
+                                  const char *file_digest,
                                   const char *file_temp_path,
                                   const char *remove_pass,
                                   const char *download_pass,
                                   const char *comment, const char *ip_address)
 {
     apr_size_t item_id;
-    apr_size_t item_index;
-    UploadItem *uitem;
-    apr_time_t current_time;
-    WriteLocker manager_locker(lock_);
 
-    create_item_id_index(&item_id, &item_index);
-    current_time = apr_time_now();
-
-    uitem = UploadItem::get_instance
-        (pool, item_id, item_index, file_size, current_time, ip_address,
-         file_name, file_mime, file_digest, remove_pass, download_pass,
-         comment);
-
-    // 古いアイテムを削除
-    while (item_list_->is_full(file_size)) {
-        UploadItem *old_uitem;
-
-        old_uitem = AS_UITEM(item_list_->get_by_index(item_list_->size()-1));
-
-        item_writer_.remove(pool, old_uitem);
-        thumbnail_list_->remove(old_uitem->get_id());
-        item_list_->remove(old_uitem->get_id());
-    }
-
-    if (item_writer_.write(uitem, file_temp_path)) {
-        thumbnail_list_->add(uitem->get_id());
-    }
-    item_list_->add(uitem);
-
-    *mtime_ = current_time;
+    item_id = add_impl(pool, file_name, file_mime, file_size, file_digest,
+                       file_temp_path, remove_pass, download_pass, comment,
+                       ip_address);
 
     sync_all_item_by_catches(pool);
 
@@ -134,16 +109,7 @@ apr_size_t UploadItemManager::add(apr_pool_t *pool,
 
 void UploadItemManager::remove(apr_pool_t *pool, UploadItem *uitem)
 {
-    WriteLocker manager_locker(lock_);
-
-    REQUIRE_MANAGER_LOCKED();
-
-    // 処理の順番を変えるとまずい
-    item_writer_.remove(pool, uitem);
-    item_list_->remove(uitem->get_id());
-    thumbnail_list_->remove(uitem->get_id());
-
-    *mtime_ = apr_time_now();
+    remove_impl(pool, uitem);
 
     sync_all_item_by_catches(pool);
 }
@@ -153,6 +119,8 @@ void UploadItemManager::sync_all_item(apr_pool_t *pool, apr_size_t sync_limit)
     UploadItem::header_t *header;
     apr_size_t synced_count;
 
+    // カウンタの値は atomic に変更されるので，ロックは不要
+
     synced_count = 0;
     for (apr_size_t i = 0; i < item_list_->size(); i++) {
         header = item_list_->get_by_index(i);
@@ -268,6 +236,68 @@ UploadItemManager::UploadItemManager(apr_pool_t *pool,
 
 }
 
+apr_size_t UploadItemManager::add_impl(apr_pool_t *pool,
+                                       const char *file_name,
+                                       const char *file_mime,
+                                       apr_uint64_t file_size,
+                                       const char *file_digest,
+                                       const char *file_temp_path,
+                                       const char *remove_pass,
+                                       const char *download_pass,
+                                       const char *comment,
+                                       const char *ip_address)
+{
+    apr_size_t item_id;
+    apr_size_t item_index;
+    UploadItem *uitem;
+    apr_time_t current_time;
+    WriteLocker manager_locker(lock_);
+
+    REQUIRE_MANAGER_LOCKED();
+
+    create_item_id_index(&item_id, &item_index);
+    current_time = apr_time_now();
+
+    uitem = UploadItem::get_instance
+        (pool, item_id, item_index, file_size, current_time, ip_address,
+         file_name, file_mime, file_digest, remove_pass, download_pass,
+         comment);
+
+    // 古いアイテムを削除
+    while (item_list_->is_full(file_size)) {
+        UploadItem *old_uitem;
+
+        old_uitem = AS_UITEM(item_list_->get_by_index(item_list_->size()-1));
+
+        item_writer_.remove(pool, old_uitem);
+        thumbnail_list_->remove(old_uitem->get_id());
+        item_list_->remove(old_uitem->get_id());
+    }
+
+    if (item_writer_.write(uitem, file_temp_path)) {
+        thumbnail_list_->add(uitem->get_id());
+    }
+    item_list_->add(uitem);
+
+    *mtime_ = current_time;
+
+    return item_id;
+}
+
+void UploadItemManager::remove_impl(apr_pool_t *pool, UploadItem *uitem)
+{
+    WriteLocker manager_locker(lock_);
+
+    REQUIRE_MANAGER_LOCKED();
+
+    // 処理の順番を変えるとまずい
+    item_writer_.remove(pool, uitem);
+    item_list_->remove(uitem->get_id());
+    thumbnail_list_->remove(uitem->get_id());
+
+    *mtime_ = apr_time_now();
+}
+
 void UploadItemManager::child_init_impl(UploadItemList *item_list,
                                         ThumbnailList *thumbnail_list)
 {
